==> heptapod-rails-0.22.0.tar.gz: heptapod-rails-0.22.0/spec/graphql/mutations/merge_requests/set_wip_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Mutations::MergeRequests::SetWip do
  let(:merge_request) { create(:merge_request) }
  let(:user) { create(:user) }

  subject(:mutation) { described_class.new(object: nil, context: { current_user: user }, field: nil) }

  specify { expect(described_class).to require_graphql_authorizations(:update_merge_request) }

  describe '#resolve' do
    let(:wip) { true }
    let(:mutated_merge_request) { subject[:merge_request] }

    subject { mutation.resolve(project_path: merge_request.project.full_path, iid: merge_request.iid, wip: wip) }

    it_behaves_like 'permission level for merge request mutation is correctly verified'

    context 'when the user can update the merge request' do
      before do
        merge_request.project.add_developer(user)
      end

      it 'returns the merge request as a wip' do
        expect(mutated_merge_request).to eq(merge_request)
        expect(mutated_merge_request).to be_work_in_progress
        expect(subject[:errors]).to be_empty
      end

      it 'returns errors merge request could not be updated' do
        # Make the merge request invalid
        merge_request.allow_broken = true
        merge_request.update!(source_project: nil)

        expect(subject[:errors]).not_to be_empty
      end

      context 'when passing wip as false' do
        let(:wip) { false }

        it 'removes `wip` from the title' do
          merge_request.update(title: "WIP: working on it")

          expect(mutated_merge_request).not_to be_work_in_progress
        end

        it 'does not do anything if the title did not start with wip' do
          expect(mutated_merge_request).not_to be_work_in_progress
        end
      end
    end
  end
end

==> heptapod-rails-0.24.0rc1.tar.gz: heptapod-rails-0.24.0rc1/spec/graphql/mutations/merge_requests/set_wip_spec.rb <==
# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Mutations::MergeRequests::SetWip do
  let(:merge_request) { create(:merge_request) }
  let(:user) { create(:user) }

  subject(:mutation) { described_class.new(object: nil, context: { current_user: user }, field: nil) }

  specify { expect(described_class).to require_graphql_authorizations(:update_merge_request) }

  describe '#resolve' do
    let(:wip) { true }
    let(:mutated_merge_request) { subject[:merge_request] }

    subject { mutation.resolve(project_path: merge_request.project.full_path, iid: merge_request.iid, wip: wip) }

    it_behaves_like 'permission level for merge request mutation is correctly verified'

    context 'when the user can update the merge request' do
      before do
        merge_request.project.add_developer(user)
      end

      it 'returns the merge request as a wip' do
        expect(mutated_merge_request).to eq(merge_request)
        expect(mutated_merge_request).to be_work_in_progress
        expect(subject[:errors]).to be_empty
      end

      it 'returns errors merge request could not be updated' do
        # Make the merge request invalid
        merge_request.allow_broken = true
        merge_request.update!(source_project: nil)

        expect(subject[:errors]).not_to be_empty
      end

      context 'when passing wip as false' do
        let(:wip) { false }

        it 'removes `wip` from the title' do
          merge_request.update!(title: "WIP: working on it")

          expect(mutated_merge_request).not_to be_work_in_progress
        end

        it 'does not do anything if the title did not start with wip' do
          expect(mutated_merge_request).not_to be_work_in_progress
        end
      end
    end
  end
end
